/*********************************************/
/*   Microbial Fuel Cell                     */
/*   UDF Diffusiviy                          */
/*                                           */
/*   Michael Calder                          */
/*   University of Southern California       */
/*   NTNU                                    */
/*   August 2007                             */
/*                                           */
/*********************************************/


#include "udf.h"

DEFINE_DIFFUSIVITY(mfc_cat10,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=1.1*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_20,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=1.2*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_50,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=1.5*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_100,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=2*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_n10,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=0.9*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_n20,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=0.8*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}


DEFINE_DIFFUSIVITY(mfc_cath_n50,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=0.5*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}

DEFINE_DIFFUSIVITY(mfc_cath_200,c,t,i)
{
/* Variables */
int zone_id, a_chamber, c_chamber, a_electrode, c_electrode, membrane;
int R1, R2, P1, P2, I, S;
real d_m,spe_eff[20],spe_memb[20],diff,diff_turb;

zone_id=THREAD_ID(t);

/* Input variables that needs to be checked */
a_chamber	  = 6;	/* anode chamber id */
c_chamber	  = 4;	/* anode chamber id */
a_electrode   = 5;	/* anode and cathode electrode id */
c_electrode	  = 3;	/* anode and cathode electrode id */
membrane	  = 2;	/* membrane id */

/* Species index */
R1 = 0;
R2 = 1;
I  = 2;
P1 = 3;
P2 = 4;
S  = 5;

/* Species regular diffusion */
spe_eff[R1]=1.1e-9;
spe_eff[R2]=3*2.18e-9;
spe_eff[I]=2.2e-8;
spe_eff[P1]=1.1e-9;
spe_eff[P2]=3.2e-9;
spe_eff[S]=3.2e-9;

/* Species membrane diffusion */
spe_memb[R1]=1e-22;		/* approx 0 */
spe_memb[R2]=1e-22;		/* approx 0 */
spe_memb[I]=5.0e-10;
spe_memb[P1]=1e-22;		/* approx 0 */
spe_memb[P2]=1e-22;		/* approx 0 */
spe_memb[S]=1e-22;		/* approx 0 */

/* Turbulent diffusivity */
diff_turb = 1.98E-6;


/* Diffusivity calculations */
if(zone_id==a_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==c_chamber) {
	d_m = spe_eff[i] + diff_turb;
}
else if(zone_id==a_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==c_electrode) {
	d_m = spe_eff[i];
}
else if(zone_id==membrane) {
	d_m = spe_memb[i];
}
else {
	d_m = 0;
}


return d_m;

}
